.. sorl-thumbnail documentation master file, created by
   sphinx-quickstart on Fri Nov 12 00:51:21 2010.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to sorl-thumbnail's documentation!
==========================================

Contents:

.. toctree::
   :maxdepth: 2

   installation
   requirements
   examples
   management
   operation

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. |kvstore| replace:: Key Value Store
